@@ -1,7 +1,7 @@
-/* $Id: testminiwget.c,v 1.1 2009/12/03 18:44:32 nanard Exp $ */
+/* $Id: testminiwget.c,v 1.3 2011/05/06 16:33:53 nanard Exp $ */
 /* Project : miniupnp
  * Author : Thomas Bernard
- * Copyright (c) 2005-2009 Thomas Bernard
+ * Copyright (c) 2005-2011 Thomas Bernard
  * This software is subject to the conditions detailed in the
  * LICENCE file provided in this distribution.
  * */
@@ -9,21 +9,29 @@
 #include <stdlib.h>
 #include "miniwget.h"
 
+/**
+ * This program uses the miniwget / miniwget_getaddr function
+ * from miniwget.c in order to retreive a web ressource using
+ * a GET HTTP method, and store it in a file.
+ */
 int main(int argc, char * * argv)
 {
 	void * data;
 	int size, writtensize;
 	FILE *f;
+	char addr[64];
 	if(argc < 3) {
 		fprintf(stderr, "Usage:\t%s url file\n", argv[0]);
 		fprintf(stderr, "Example:\t%s http://www.google.com/ out.html\n", argv[0]);
 		return 1;
 	}
-	data = miniwget(argv[1], &size);
+	/*data = miniwget(argv[1], &size);*/
+	data = miniwget_getaddr(argv[1], &size, addr, sizeof(addr));
 	if(!data) {
 		fprintf(stderr, "Error fetching %s\n", argv[1]);
 		return 1;
 	}
+	printf("local address : %s\n", addr);
 	printf("got %d bytes\n", size);
 	f = fopen(argv[2], "wb");
 	if(!f) {
